.. created by sphinx-quickstart
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

jubeo : Small tool for deploying and updating development task tooling and automation. 
====================================================

.. toctree::
   :maxdepth: 1

   source/introduction
   source/installation
   source/quick_start

   source/users_guide
   source/tutorials/index
   source/reference                    
   source/troubleshooting
   source/glossary

   source/general_info              
   source/dev_guide
   source/changelog
   source/news

   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
